/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.enums;

import java.util.HashMap;

import com.redhat.rhevm.api.model.DiskStatus;

public enum PowerShellImageStatus {
    Unassigned(0), OK(1), LOCKED(2), INVALID(3), ILLEGAL(4);

    private static HashMap<Integer, PowerShellImageStatus> mapping;
    static {
        mapping = new HashMap<Integer, PowerShellImageStatus>();
        for (PowerShellImageStatus value : values()) {
            mapping.put(value.value, value);
        }
    }

    private int value;

    private PowerShellImageStatus(int value) {
        this.value = value;
    }

    public int getValue() {
        return value;
    }

    public DiskStatus map() {
        switch (this) {
        case OK:
            return DiskStatus.OK;
        case LOCKED:
            return DiskStatus.LOCKED;
        case ILLEGAL:
            return DiskStatus.ILLEGAL;
        default:
            assert false : this;
            return null;
        }
    }

    public static PowerShellImageStatus forValue(int value) {
        return mapping.get(value);
    }
}
