/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.model;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.common.util.StatusUtils;
import com.redhat.rhevm.api.model.DataCenter;
import com.redhat.rhevm.api.model.DataCenterStatus;
import com.redhat.rhevm.api.model.Version;
import com.redhat.rhevm.api.powershell.enums.PowerShellStorageType;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;

public class PowerShellDataCenter {

    public static List<DataCenter> parse(PowerShellParser parser, String output) {
        List<DataCenter> ret = new ArrayList<DataCenter>();

        for (PowerShellParser.Entity entity : parser.parse(output)) {
            DataCenter dataCenter = new DataCenter();

            dataCenter.setId(entity.get("datacenterid"));
            dataCenter.setName(entity.get("name"));
            dataCenter.setDescription(entity.get("description"));
            dataCenter.setStorageType(entity.get("type", PowerShellStorageType.class).map().value());
            dataCenter.setStatus(StatusUtils.create(entity.get("status")));
            dataCenter.setVersion(entity.get("compatibilityversion", Version.class));

            ret.add(dataCenter);
        }

        return ret;
    }

    private static DataCenterStatus parseStatus(String s) {
        if (s.equals("Uninitialized"))   return DataCenterStatus.UNINITIALIZED;
        if (s.equals("Up"))              return DataCenterStatus.UP;
        if (s.equals("Maintenance"))     return DataCenterStatus.MAINTENANCE;
        if (s.equals("Not Operational")) return DataCenterStatus.NOT_OPERATIONAL;
        if (s.equals("Non-Responsive"))  return DataCenterStatus.PROBLEMATIC;
        if (s.equals("Contend"))         return DataCenterStatus.CONTEND;
        else assert false : s;
        return null;
    }
}
