/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.model;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.model.Role;
import com.redhat.rhevm.api.model.User;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;

public class PowerShellRole {

    private static String ROLE_TYPE = "RhevmCmd.CLIRole";
    private static String PERMISSION_TYPE = "RhevmCmd.CLIPermission";

    public static List<Role> parse(PowerShellParser parser, String output) {
        return parse(parser, null, output);
    }

    public static List<Role> parse(PowerShellParser parser, String userId, String output) {
        List<Role> ret = new ArrayList<Role>();

        for (PowerShellParser.Entity entity : parser.parse(output)) {
            if (ROLE_TYPE.equals(entity.getType())) {
                Role role = new Role();
                role.setId(entity.get("id"));
                role.setName(entity.get("name"));
                role.setDescription(entity.get("description"));
                ret.add(addUser(role, userId));
            } else if (PERMISSION_TYPE.equals(entity.getType())) {
                Role role = new Role();
                role.setId(entity.get("roleid"));
                role.setName(entity.get("rolename"));
                ret.add(addUser(role, userId));
            }
        }

        return ret;
    }

    private static Role addUser(Role role, String userId) {
        if (userId != null) {
            role.setUser(new User());
            role.getUser().setId(userId);
        }
        return role;
    }
}
