/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.List;
import java.util.concurrent.Executor;

import com.redhat.rhevm.api.common.util.LinkHelper;
import com.redhat.rhevm.api.model.Domain;
import com.redhat.rhevm.api.model.User;
import com.redhat.rhevm.api.model.Users;
import com.redhat.rhevm.api.powershell.model.PowerShellUser;
import com.redhat.rhevm.api.powershell.util.PowerShellCmd;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;
import com.redhat.rhevm.api.powershell.util.PowerShellUtils;
import com.redhat.rhevm.api.resource.DomainUserResource;
import com.redhat.rhevm.api.resource.DomainUsersResource;

public class PowerShellDomainUsersResource extends InjectableUriProviderBase implements DomainUsersResource {

    private PowerShellDomainResource parent;

    public PowerShellDomainUsersResource(PowerShellDomainResource parent,
                                         Executor executor,
                                         PowerShellPoolMap shellPools,
                                         PowerShellParser parser) {
        super(executor, shellPools, parser);
        this.parent = parent;
    }

    public String getDomainName() {
        return parent.getId();
    }

    @Override
    public Users list() {
        StringBuilder buf = new StringBuilder();

        buf.append("select-user -ad ");
        buf.append("-domain " + PowerShellUtils.escape(getDomainName()));
        buf.append(" | ? ");
        buf.append("{ !$_.isgroup() }");

        Users ret = new Users();
        for (User user : runAndParse(buf.toString())) {
            ret.getUsers().add(addLinks(user));
        }
        return ret;
    }

    @Override
    public DomainUserResource getDomainUserSubResource(String id) {
        return new PowerShellDomainUserResource(this, id);
    }

    protected List<User> runAndParse(String command) {
        return PowerShellUser.parse(getParser(), PowerShellCmd.runCommand(getPool(), command));
    }

    public User runAndParseSingle(String command) {
        List<User> users = runAndParse(command);
        return !users.isEmpty() ? users.get(0) : null;
    }

    public User addLinks(User user) {
        user.setDomain(new Domain());
        user.getDomain().setId(getDomainName());

        user.getLinks().clear();
        return LinkHelper.addLinks(getUriInfo(), user);
    }
}
