/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.List;

import com.redhat.rhevm.api.common.util.LinkHelper;
import com.redhat.rhevm.api.model.Domain;
import com.redhat.rhevm.api.model.Domains;
import com.redhat.rhevm.api.powershell.model.PowerShellDomain;
import com.redhat.rhevm.api.powershell.util.PowerShellCmd;
import com.redhat.rhevm.api.resource.DomainResource;
import com.redhat.rhevm.api.resource.DomainsResource;

public class PowerShellDomainsResource extends InjectableUriProviderBase implements DomainsResource {

    private String[] SUB_COLLECTIONS = { "groups", "users" };

    @Override
    public Domains list() {
        StringBuilder buf = new StringBuilder();

        buf.append("foreach ($u in select-user) { ");
        buf.append( "$u.domain ");
        buf.append("}");

        Domains ret = new Domains();
        for (Domain domain : runAndParse(buf.toString())) {
            ret.getDomains().add(addLinks(domain));
        }
        return ret;
    }

    public DomainResource getDomainSubResource(String id) {
        return new PowerShellDomainResource(this, id);
    }

    private List<Domain> runAndParse(String command) {
        return PowerShellDomain.parse(getParser(), PowerShellCmd.runCommand(getPool(), command));
    }

    public Domain addLinks(Domain domain) {
        domain = LinkHelper.addLinks(getUriInfo(), domain);

        domain.getLinks().clear();
        for (String collection : SUB_COLLECTIONS) {
            LinkHelper.addLink(domain, collection, LinkHelper.LinkFlags.NONE);
        }

        return domain;
    }
}
