/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.concurrent.Executor;

import javax.ws.rs.core.Response;

import com.redhat.rhevm.api.common.resource.UriInfoProvider;
import com.redhat.rhevm.api.model.Action;
import com.redhat.rhevm.api.model.Snapshot;
import com.redhat.rhevm.api.model.VM;
import com.redhat.rhevm.api.resource.CreationResource;
import com.redhat.rhevm.api.resource.SnapshotResource;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;
import com.redhat.rhevm.api.powershell.util.PowerShellUtils;

public class PowerShellSnapshotResource
    extends AbstractPowerShellActionableResource<Snapshot>
    implements SnapshotResource {

    private PowerShellSnapshotsResource parent;

    public PowerShellSnapshotResource(String id,
                                      Executor executor,
                                      PowerShellPoolMap shellPools,
                                      PowerShellParser parser,
                                      PowerShellSnapshotsResource parent,
                                      UriInfoProvider uriProvider) {
        super(id, executor, uriProvider, shellPools, parser);
        this.parent = parent;
    }

    protected Snapshot getModel() {
        Snapshot actionParent = super.getModel();
        actionParent.setVm(new VM());
        actionParent.getVm().setId(parent.getVmId());
        return actionParent;
    }

    @Override
    public Snapshot get() {
        return parent.buildFromDisk(parent.getDiskSnapshot(getId()));
    }

    @Override
    public Response restore(Action action) {
        StringBuilder buf = new StringBuilder();

        buf.append("restore-vm");
        buf.append(" -vmid " + PowerShellUtils.escape(parent.getVmId()));
        buf.append(" -vmsnapshotid " + PowerShellUtils.escape(getId()));

        return doAction(getUriInfo(), new CommandRunner(action, buf.toString(), getPool()));
    }

    @Override
    public CreationResource getCreationSubresource(String ids) {
        return new PowerShellCreationResource(ids,
                                              getExecutor(),
                                              getUriProvider(),
                                              getShellPools(),
                                              getParser());
    }
}
