/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.List;

import javax.ws.rs.core.UriInfo;

import com.redhat.rhevm.api.common.util.JAXBHelper;
import com.redhat.rhevm.api.common.util.LinkHelper;
import com.redhat.rhevm.api.model.StorageDomain;
import com.redhat.rhevm.api.model.VM;
import com.redhat.rhevm.api.model.VMs;
import com.redhat.rhevm.api.powershell.model.PowerShellVM;
import com.redhat.rhevm.api.powershell.util.PowerShellCmd;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;
import com.redhat.rhevm.api.powershell.util.PowerShellUtils;
import com.redhat.rhevm.api.resource.StorageDomainContentResource;
import com.redhat.rhevm.api.resource.RemovableStorageDomainContentsResource;

public class PowerShellStorageDomainVmsResource
    extends AbstractPowerShellStorageDomainContentsResource<VM>
    implements RemovableStorageDomainContentsResource<VMs, VM> {

    public PowerShellStorageDomainVmsResource(PowerShellStorageDomainResource parent,
                                              PowerShellPoolMap shellPools,
                                              PowerShellParser parser) {
        super(parent, shellPools, parser);
    }

    public List<PowerShellVM> runAndParse(String command) {
        return PowerShellVM.parse(getParser(), PowerShellCmd.runCommand(getPool(), command), null);
    }

    @Override
    public VM runAndParseSingle(String command) {
        List<PowerShellVM> vms = runAndParse(command);

        return !vms.isEmpty() ? vms.get(0) : null;
    }

    @Override
    public VM addLinks(UriInfo uriInfo, VM vm) {
        vm = JAXBHelper.clone("vm", VM.class, vm);

        vm.setStorageDomain(new StorageDomain());
        vm.getStorageDomain().setId(getStorageDomainId());

        return LinkHelper.addLinks(uriInfo, vm);
    }

    @Override
    public VMs list() {
        StringBuilder buf = new StringBuilder();

        String dataCenterArg = getDataCenterArg(buf);

        buf.append("get-vmimportcandidates");
        buf.append(" -showall");
        buf.append(" -datacenterid " + dataCenterArg);
        buf.append(" -storagedomainid " + PowerShellUtils.escape(getStorageDomainId()));

        VMs ret = new VMs();
        for (PowerShellVM vm : runAndParse(buf.toString())) {
            ret.getVMs().add(addLinks(getUriInfo(), vm));
        }
        return ret;
    }

    public StorageDomainContentResource<VM> getStorageDomainContentSubResource(String id) {
        return new PowerShellStorageDomainVmResource(this, id, executor, this, shellPools, getParser());
    }

    @Override
    public void remove(String id) {
        StringBuilder buf = new StringBuilder();
        String dataCenterArg = getDataCenterArg(buf);
        buf.append("remove-vmfromexportdomain");
        buf.append(" -vmid " + PowerShellUtils.escape(id));
        buf.append(" -datacenterid " + dataCenterArg);
        buf.append(" -storagedomainid " + PowerShellUtils.escape(getStorageDomainId()));
        runAndParse(buf.toString());
    }
}
