/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.util;

import java.util.concurrent.ExecutorService;

import com.redhat.rhevm.api.common.invocation.Current;
import com.redhat.rhevm.api.common.security.auth.Principal;
import com.redhat.rhevm.api.common.util.ReapedMap;

@SuppressWarnings("serial")
public class PowerShellPoolMap extends ReapedMap<Principal, PowerShellPool> {

    private static final long REAP_AFTER = 10 * 60 * 1000L; // 10 minutes

    private ExecutorService executor;
    private Current current;

    public PowerShellPoolMap() {
        super(REAP_AFTER, true);
    }

    public void setExecutor(ExecutorService executor) {
        this.executor = executor;
    }

    public void setCurrent(Current current) {
        this.current = current;
    }

    public synchronized PowerShellPool get() {
        PowerShellPool pool = null;
        Principal principal = current.get(Principal.class);
        if (principal != null) {
            pool = super.get(principal);
            if (pool == null) {
                pool = new PowerShellPool(executor, principal, current);
                super.put(principal, pool);
                super.reapable(principal);
            }
        }
        return pool;
    }
}
